<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">


<!-- КОРНЕВОЙ ШАБЛОН -->
<xsl:template match="/">
	<html>
	<head>
		<!-- Формирование заголовка страницы -->
		<xsl:call-template name="PageHeader"/>
	</head>
	<body>
		<!-- Отображение заголовка страницы с подсветкой текущего шага -->
		<xsl:call-template name="BodyHeader"/>
		<!-- Отображение содержимого страницы в соответствии с номером текущего шага -->
		<xsl:apply-templates select="PrintJobList"/>
	</body>
	</html>
</xsl:template>


<!-- ФОРМИРОВАНИЕ ЗАГОЛОВКА СТРАНИЦЫ -->
<xsl:template name="PageHeader">
	<title>УПРАВЛЕНИЕ ПЕЧАТЬЮ <xsl:value-of select="@job-id"/></title>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
	<!-- Включение периодического обновления страницы при отсутствии заданий для печати -->
	<xsl:if test='//@step = 0'>
		<meta http-equiv="Refresh" content="5" url="printcontrol.php" target="_blank"/>
	</xsl:if>
	<!-- Включение периодического обновления страницы на третьем шаге -->
	<xsl:if test='//@step = 3'>
		<meta http-equiv="Refresh" content="3" url="printcontrol.php" target="_blank"/>
	</xsl:if>
	<link rel="stylesheet" type="text/css" href="printcontrol.css"/>
</xsl:template>


<!-- ОТОБРАЖЕНИЕ ЗАГОЛОВКА СТРАНИЦЫ С ПОДСВЕТКОЙ ТЕКУЩЕГО ШАГА -->
<xsl:template name="BodyHeader">
	<div class="pageheader">
		<p class="showprotocol"><a href="protocol.php" target="blank">Просмотр регистрации<br/>вывода документов на печать</a></p>
		<h1 class="pageheader">УПРАВЛЕНИЕ ПЕЧАТЬЮ ДОКУМЕНТОВ</h1>
		<table><tr class="step">
			<td class="blank">&#160;</td>
			<xsl:if test='//PrintJobList/@step != 1'>
				<td class="steplabel"><span class="stepnum">1</span>Выбор<br/>задания<br/>из списка</td>
			</xsl:if><xsl:if test='//PrintJobList/@step = 1'>
				<td class="steplabel nowstep"><span class="stepnum">1</span>Выбор<br/>задания<br/>из списка</td>
			</xsl:if>
			<td class="stepline"><div class="stepline"></div></td>
			<xsl:if test='//PrintJobList/@step != 2'>
				<td class="steplabel"><span class="stepnum">2</span>Заполнение<br/>реквизитов<br/>документа</td>
			</xsl:if><xsl:if test='//PrintJobList/@step = 2'>
				<td class="steplabel nowstep"><span class="stepnum">2</span>Заполнение<br/>реквизитов<br/>документа</td>
			</xsl:if>
			<td class="stepline"><div class="stepline"></div></td>
			<xsl:if test='//PrintJobList/@step != 3'>
				<td class="steplabel"><span class="stepnum">3</span>Печать<br/>документа<br/>и реквизитов</td>
			</xsl:if><xsl:if test='//PrintJobList/@step = 3'>
				<td class="steplabel nowstep"><span class="stepnum">3</span>Печать<br/>документа<br/>и реквизитов</td>
			</xsl:if>
			<td class="stepline"><div class="stepline"></div></td>
			<xsl:if test='//PrintJobList/@step != 4'>
				<td class="steplabel"><span class="stepnum">4</span>Заполнение<br/>учетной<br/>карточки</td>
			</xsl:if><xsl:if test='//PrintJobList/@step = 4'>
				<td class="steplabel nowstep"><span class="stepnum">4</span>Заполнение<br/>учетной<br/>карточки</td>
			</xsl:if>
			<td class="blank">&#160;</td>
		</tr></table>
	</div>
</xsl:template>


<!-- ОСНОВНОЙ ШАБЛОН ОТОБРАЖЕНИЯ СТРАНИЦЫ -->
<xsl:template match="PrintJobList">
	<form name="form" method="post" action="printcontrol.php">
	<xsl:choose>
	<xsl:when test="@step=1">
		<xsl:call-template name="Step1"/>
	</xsl:when>
	<xsl:when test="@step=2">
		<xsl:call-template name="Step2"/>
	</xsl:when>
	<xsl:when test="@step=3">
		<xsl:call-template name="Step3"/>
	</xsl:when>
	<xsl:when test="@step=4">
		<xsl:call-template name="Step4"/>
	</xsl:when>
	<xsl:otherwise>
		<xsl:call-template name="Step0"/>
	</xsl:otherwise>
	</xsl:choose>
	</form>
</xsl:template>


<!-- ШАБЛОН ДЛЯ 0-ГО ШАГА -->
<xsl:template name="Step0">
	<div class="step0">
		<br/><br/><br/>
		<h1 class="pageheader">По состоянию на <xsl:value-of select="@date"/>&#160;<xsl:value-of select="@time"/></h1>
		<br/>
		<h1 class="pageheader">ЗАДАНИЙ НА ПЕЧАТЬ НЕТ!</h1>
		<br/>
		<h1 class="pageheader">Производится автоматический запрос списка заданий на печать.</h1>
	</div>
</xsl:template>


<!-- ШАБЛОН ДЛЯ 1-ГО ШАГА -->
<xsl:template name="Step1">
	<div class="printlist">
		<p class="step">1-й шаг: Выберите из списка задание для печати или <a href="printcontrol.php">обновите страницу</a></p>
		<br/><h1 class="pageheader">Список заданий на печать по состоянию на <xsl:value-of select="@date"/>&#160;
			<xsl:value-of select="@time"/></h1>
		<xsl:apply-templates select="JobList"/>
	</div>
</xsl:template>


<!-- ШАБЛОН ДЛЯ 2-ГО ШАГА -->
<xsl:template name="Step2">
	<div class="printlist">
		<p class="step">2-й шаг: Заполните реквизиты документа для его маркировки при печати</p>
		<br/><h1 class="pageheader">Выбрано задание на печать</h1>
		<input type="hidden" name="job-id" value="{//PrintJobList/PrintJob/@job-id}"/>
		<table class="printlist">
		<xsl:call-template name="JobHeader">
			<xsl:with-param name="First">Отправка&#xA;на печать</xsl:with-param>
			<xsl:with-param name="Last">Отмена&#xA;печати</xsl:with-param>
		</xsl:call-template>
		<xsl:for-each select="PrintJob">
			<xsl:call-template name="JobString">
				<xsl:with-param name="First">Отправить</xsl:with-param>
				<xsl:with-param name="Last">Отменить</xsl:with-param>
			</xsl:call-template>
			<tr class="printlist">
				<td class="button" colspan="9"><h1 class="pageheader">Реквизиты документа для печати</h1></td>
			</tr><tr class="printlist">
				<td class="label" colspan="4">Основание для степени секретности:</td>
				<td class="input" colspan="6"><input type="input" name="punkt" value="пункт перечня"/></td>
			</tr><tr class="printlist">
				<td class="label" colspan="4">Учетный номер:</td>
				<td class="input" colspan="6"><input type="input" name="mac-inv-num" value="мб"/></td>
			</tr><tr class="printlist">
				<td class="label" colspan="4">Количество экземпляров:</td>
				<td class="input" colspan="6"><input type="input" name="copies" value="1"/></td>
			</tr><tr class="printlist">
				<td class="label" colspan="4">Номер помещения:</td>
				<td class="input" colspan="6"><input type="input" name="mac-workplace-id" value="{job-originating-user-name/@dislocation}"/></td>
			</tr><tr class="printlist">
				<td class="label" colspan="4">Адреса рассылки - 1:</td>
				<td class="input" colspan="6"><input type="input" name="adr1" value="Экз.1 - В дело"/></td>
			</tr><tr class="printlist">
				<td class="label" colspan="4">- 2:</td>
				<td class="input" colspan="6"><input type="input" name="adr2" value="Экз.2 - В адрес"/></td>
			</tr>
			<tr class="printlist">
				<td class="label" colspan="4">- 3:</td>
				<td class="input" colspan="6"><input type="input" name="adr3" value=""/></td>
			</tr><tr class="printlist">
				<td class="label" colspan="4">- 4:</td>
				<td class="input" colspan="6"><input type="input" name="adr4" value=""/></td>
			</tr><tr class="printlist">
				<td class="label" colspan="4">- 5:</td>
				<td class="input" colspan="6"><input type="input" name="adr5" value=""/></td>
			</tr><tr class="printlist">
				<td class="label" colspan="4">Исполнитель:</td>
				<td class="input" colspan="6"><input type="input" name="user-fullname" value="{job-originating-user-name/@name}"/></td>
			</tr><tr class="printlist">
				<td class="label" colspan="4">Телефон:</td>
				<td class="input" colspan="6"><input type="input" name="mac-owner-phone" value="{job-originating-user-name/@phone}"/></td>
			</tr><tr class="printlist">
				<td class="label" colspan="4">Отпечатал:</td>
				<td class="input" colspan="6"><input type="input" name="printuser-fullname" value="{//PrintJobList/user-prn/@name}"/></td>
			</tr><tr class="printlist">
				<td class="label" colspan="4"><input class="buttonyes" type="submit" name="{@job-id}" value="Отправить"/></td>
				<td class="button" colspan="1">&#160;</td>
				<td class="input" colspan="5"><input class="buttonno" type="submit" name="{@job-id}" value="Отменить"/></td>
			</tr>
		</xsl:for-each>
		</table>
	</div>
</xsl:template>


<!-- ШАБЛОН ДЛЯ 3-ГО ШАГА -->
<xsl:template name="Step3">
	<div class="printlist">
		<p class="step">3-й шаг: Напечатайте заданное колическво экземпляров документа<br/>и его реквизитов на оборотной стороне последнего листа</p>
		<br/><h1 class="pageheader">Выбрано задание на печать</h1>
		<table class="printlist">
		<xsl:call-template name="JobHeader"/>
		<xsl:for-each select="PrintJob">
			<xsl:call-template name="JobString"/>
		</xsl:for-each>
		<tr class="printlist">
			<td class="button" colspan="10"><h1 class="pageheader">Список экземпляров документа и реквизитов для печати</h1></td>
		</tr>
		<tr class="printlist">
			<th class="printlist">Печать<br/>задания</th>
			<th class="printlist">Иденти-<br/>фикатор</th>
			<th class="printlist">Пользователь</th>
			<th class="printlist">Время<br/>выдачи</th>
			<th class="printlist" colspan="4">Содержимое печати</th>
			<th class="printlist">Отмена<br/>печати</th>
		</tr>
		<xsl:for-each select="PrintList/Job">
			<xsl:if test='job-name/@type = "document"'>
				<xsl:call-template name="PrintJobString">
					<xsl:with-param name="Name">
						<xsl:value-of select='job-name/@copie'/>-й экз. СОДЕРЖИМОГО ДОКУМЕНТА
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if><xsl:if test='job-name/@type = "rekvizit"'>
				<xsl:call-template name="PrintJobString">
					<xsl:with-param name="Name">
						<xsl:value-of select='job-name/@copie'/>-й экз. РЕКВИЗИТОВ на оборотной стороне последнего листа
					</xsl:with-param>
					<xsl:with-param name="Class"> rekvizit</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
		</table>
	</div>
</xsl:template>


<!-- ШАБЛОН ДЛЯ 4-ГО ШАГА -->
<xsl:template name="Step4">
	<div class="printlist">
		<p class="step">4-й шаг: Заполните поля учетной карточки документа</p>
		<br/><h1 class="pageheader">Обработано задание на печать</h1>
		<table class="printlist">
		<xsl:for-each select="Protocol/PrintJob">
			<xsl:call-template name="ProtJobHeader"/>
			<xsl:call-template name="ProtJobString"/>
		</xsl:for-each>
		</table>
		<br/><h1 class="pageheader">Введите значения полей учетной карточки документа</h1>
		<xsl:for-each select="Protocol">
		<input type="hidden" name="job-id" value="{@job-id}"/>
		<table class="printlist">
			<tr class="printlist">
				<td class="label">Дата выдачи:</td>
				<td class="input"><input type="input" name="date" value="{PrintJob/time-at-creation/@date}"/></td>
			</tr><tr class="printlist">
				<td class="label">Время выдачи:</td>
				<td class="input"><input type="input" name="time" value="{PrintJob/time-at-creation/@time}"/></td>
			</tr><tr class="printlist">
				<td class="label">Устройство выдачи:</td>
				<td class="input"><input type="input" name="unit" value="{PrintJob/@job-printer-uri}"/></td>
			</tr><tr class="printlist">
				<td class="label">Учетный номер:</td>
				<td class="input"><input type="input" name="number" value="{PrintJob/@mac-inv-num}"/></td>
			</tr><tr class="printlist">
				<td class="label">Краткое содержание:</td>
				<td class="input"><input type="input" name="name" value=""/></td>
<!--			</tr><tr class="printlist">
				<td class="label">Уровень конфиденциальности:</td>
				<td class="input"><input type="input" name="level" value="{PrintJob/mac-job-mac/@level}"/></td>
			</tr><tr class="printlist">
				<td class="label">Идентификатор субъекта доступа:</td>
				<td class="input"><input type="input" name="user" value="{PrintJob/job-originating-user-name/@login}"/></td>
			</tr><tr class="printlist">
				<td class="label">Фамилия пользователя:</td>
				<td class="input"><input type="input" name="fio" value="{PrintJob/job-originating-user-name/@name}"/></td>
-->			</tr><tr class="printlist">
				<td class="label">Количество листов:</td>
				<td class="input"><input type="input" name="pages" value=""/></td>
			</tr><tr class="printlist">
				<td class="label">Количество копий:</td>
				<td class="input"><input type="input" name="copies" value="{PrintJob/@copies}"/></td>
			</tr><tr class="printlist">
				<td class="label">Результат выдачи:</td>
				<td class="input"><input type="input" name="status" value="Успешно"/></td>
			</tr><tr class="printlist">
				<td class="label">Брак:</td>
				<td class="input"><input type="input" name="brak" value=""/></td>
			</tr><tr class="printlist">
				<td class="button"><input class="buttonyes" type="submit" name="{@job-id}" value="Запомнить"/></td>
				<td class="button"><input class="buttonno" type="submit" name="{@job-id}" value="Не запоминать"/></td>
			</tr>
		</table>
		</xsl:for-each>
	</div>
</xsl:template>


<!-- ШАБЛОН ДЛЯ СПИСКА НЕМАРКИРОВАННЫХ ЗАДАНИЙ -->
<xsl:template match="JobList">
	<table class="printlist">
	<xsl:call-template name="JobHeader">
		<xsl:with-param name="First">Выбор&#xA;задания</xsl:with-param>
		<xsl:with-param name="Last">Удаление&#xA;задания</xsl:with-param>
	</xsl:call-template>
	<xsl:for-each select="Job">
		<xsl:call-template name="JobString">
			<xsl:with-param name="First">Выбрать</xsl:with-param>
			<xsl:with-param name="Last">Удалить</xsl:with-param>
			<xsl:with-param name="Class">printlist</xsl:with-param>
		</xsl:call-template>
	</xsl:for-each>
	</table>
</xsl:template>


<!-- ШАБЛОН ДЛЯ ЗАГОЛОВКА СПИСКА ЗАДАНИЙ -->
<xsl:template name="JobHeader">
	<xsl:param name="First"> </xsl:param>
	<xsl:param name="Last"> </xsl:param>
	<tr class="printlist">
		<xsl:if test='$First = ""'>
			<th class="button">&#160;</th>
		</xsl:if><xsl:if test='$First != ""'>
			<th class="printlist"><xsl:value-of select="$First"/></th>
		</xsl:if>
		<th class="printlist">Иденти-<br/>фикатор</th>
		<th class="printlist">Пользователь<br/>ФИО, тел., № к.</th>
		<th class="printlist">Время<br/>выдачи</th>
		<th class="printlist">Имя файла</th>
		<th class="printlist">Принтер</th>
		<th class="printlist">Степень<br/>секретности</th>
		<th class="printlist">Формат<br/>бумаги</th>
		<xsl:if test='$Last = ""'>
			<th class="button">&#160;</th>
		</xsl:if><xsl:if test='$Last != ""'>
			<th class="printlist"><xsl:value-of select="$Last"/></th>
		</xsl:if>
	</tr>
</xsl:template>


<!-- ШАБЛОН ДЛЯ ЗАГОЛОВКА ЗАДАНИЯ В ПРОТОКОЛ -->
<xsl:template name="ProtJobHeader">
	<xsl:param name="First"> </xsl:param>
	<xsl:param name="Last"> </xsl:param>
	<tr class="printlist">
		<xsl:if test='$First = ""'>
			<th class="button">&#160;</th>
		</xsl:if><xsl:if test='$First != ""'>
			<th class="printlist"><xsl:value-of select="$First"/></th>
		</xsl:if>
		<th class="printlist">Иденти-<br/>фикатор</th>
		<th class="printlist">Исполнил<br/>Отпечатал</th>
		<th class="printlist">Время<br/>выдачи</th>
		<th class="printlist">Имя файла</th>
		<th class="printlist">Принтер</th>
		<th class="printlist">Степень секретности<br/>(основание)</th>
		<th class="printlist">Формат<br/>бумаги</th>
		<xsl:if test='$Last = ""'>
			<th class="button">&#160;</th>
		</xsl:if><xsl:if test='$Last != ""'>
			<th class="printlist"><xsl:value-of select="$Last"/></th>
		</xsl:if>
	</tr>
</xsl:template>


<!-- ШАБЛОН ДЛЯ ОТОБРАЖЕНИЯ ПАРАМЕТРОВ ЗАДАНИЯ -->
<xsl:template name="JobString">
	<xsl:param name="First"></xsl:param>
	<xsl:param name="Last"></xsl:param>
	<xsl:param name="Class">printjob</xsl:param>
	<tr class="printlist">
		<xsl:if test='$First = ""'>
			<td class="button">&#160;</td>
		</xsl:if><xsl:if test='$First != ""'>
			<td class="button"><input class="buttonyes" type="submit" name="{@job-id}" value="{$First}"/></td>
		</xsl:if>
		<td class="{$Class}"><xsl:value-of select='@job-id'/></td>
		<td class="{$Class}"><xsl:value-of select='job-originating-user-name/@login'/>
			<p class="date"><xsl:value-of select='job-originating-user-name/@name'/>,&#160;тел.<xsl:value-of select='job-originating-user-name/@phone'/>,&#160;пом.<xsl:value-of select='job-originating-user-name/@dislocation'/></p>
		</td>
		<td class="{$Class}"><xsl:value-of select='time-at-creation/@time'/>
			<xsl:if test='time-at-creation/@date != //PrintJobList/@date'>
				<br/><p class="date"><xsl:value-of select='time-at-creation/@date'/></p>
			</xsl:if>
		</td>
		<td class="{$Class}"><xsl:value-of select='@job-name'/></td>
		<td class="{$Class}"><xsl:value-of select='@printer-uri'/></td>
		<td class="{$Class}"><xsl:value-of select='mac-job-mac/@level'/></td>
		<td class="{$Class}"><xsl:value-of select='@PageSize'/></td>
		<xsl:if test='$Last = ""'>
			<td class="button">&#160;</td>
		</xsl:if><xsl:if test='$Last != ""'>
			<td class="button"><input class="buttonno" type="submit" name="{@job-id}" value="{$Last}"/></td>
		</xsl:if>
	</tr>
</xsl:template>


<!-- ШАБЛОН ДЛЯ ОТОБРАЖЕНИЯ ПАРАМЕТРОВ ЗАДАНИЯ В ПРОТОКОЛ -->
<xsl:template name="ProtJobString">
	<xsl:param name="First"></xsl:param>
	<xsl:param name="Last"></xsl:param>
	<xsl:param name="Class">printjob</xsl:param>
	<tr class="printlist">
		<xsl:if test='$First = ""'>
			<td class="button">&#160;</td>
		</xsl:if><xsl:if test='$First != ""'>
			<td class="button"><input class="buttonyes" type="submit" name="{@job-id}" value="{$First}"/></td>
		</xsl:if>
		<td class="{$Class}"><xsl:value-of select='@job-id'/></td>
		<td class="{$Class}"><xsl:value-of select='job-originating-user-name/@name'/> (<xsl:value-of select='job-originating-user-name/@login'/>)
			<br/><xsl:value-of select='@printuser-fullname'/> (<xsl:value-of select='@mac-job-user-name'/>)
		</td>
		<td class="{$Class}"><xsl:value-of select='time-at-creation/@time'/>
			<xsl:if test='time-at-creation/@date != //PrintJobList/@date'>
				<br/><p class="date"><xsl:value-of select='time-at-creation/@date'/></p>
			</xsl:if>
		</td>
		<td class="{$Class}"><xsl:value-of select='@job-name'/></td>
		<td class="{$Class}"><xsl:value-of select='@printer-uri'/></td>
		<td class="{$Class}"><xsl:value-of select='mac-job-mac/@level'/>
			<br/>(<xsl:value-of select='@punkt'/>)
		</td>
		<td class="{$Class}"><xsl:value-of select='@PageSize'/></td>
		<xsl:if test='$Last = ""'>
			<td class="button">&#160;</td>
		</xsl:if><xsl:if test='$Last != ""'>
			<td class="button"><input class="buttonno" type="submit" name="{@job-id}" value="{$Last}"/></td>
		</xsl:if>
	</tr>
</xsl:template>


<!-- ШАБЛОН ДЛЯ ОТОБРАЖЕНИЯ ПАРАМЕТРОВ ДОКУМЕНТОВ И РЕКВИЗИТОВ -->
<xsl:template name="PrintJobString">
	<xsl:param name="Name"></xsl:param>
	<xsl:param name="Class"></xsl:param>
	<tr class="printlist">
	<td class="button"><input class="buttonyes" type="submit" name="{@job-id}" value="Печать"/></td>
	<td class="printlist{$Class}"><xsl:value-of select='@job-id'/></td>
	<td class="printlist{$Class}"><xsl:value-of select='job-originating-user-name/@login'/>
		<p class="date"><xsl:value-of select='job-originating-user-name/@name'/>,&#160;тел.<xsl:value-of select='job-originating-user-name/@phone'/>,&#160;пом.<xsl:value-of select='job-originating-user-name/@dislocation'/></p>
	</td>
	<td class="printlist{$Class}"><xsl:value-of select='time-at-creation/@time'/>
		<xsl:if test='time-at-creation/@date != //PrintJobList/@date'>
			<br/><p class="date"><xsl:value-of select='time-at-creation/@date'/></p>
		</xsl:if>
	</td>
	<td class="printlist left{$Class}" colspan="4"><xsl:value-of select='$Name'/></td>
	<td class="button"><input class="buttonno" type="submit" name="{@job-id}" value="Удалить"/></td>
	</tr>
</xsl:template>


</xsl:stylesheet>
